INTERNAL: The log likelihood function
hopit_negLL(parameters = model$coef, model, collapse = TRUE,
use_weights, negative = TRUE)model parameters (optional). If the parameters are not delivered, they are taken from model$coef.
a hopit object.
a logical indicating whether to sum the individual LL contributions.
a logical indicating whether to use model weights.
a logical indicating whether the function should return negative.